@@ -2,13 +2,17 @@ from ..common.grammar_types  import type_from_type, type_from_value, BaseType
 from ..common.grammar  import delimitedList, end_of_file, generate_grammar
 import pyparsing as pp
 from ..common.misc import OrderedDict
-from .conf_containers import Section
+from .configuration_containers import Section
 from .options import Option
 import numpy as np
 import inspect
 from .misc import cache
 import itertools
 
+_parse_all_name = 'parse_all' if \
+  'parse_all' in inspect.getfullargspec(pp.Or.parseString).args \
+  else 'parseAll'
+
 def unique_dict(values):
     out = dict(values)
     if len(values) != len(out):
@@ -309,7 +313,7 @@ def add_excluded_names_condition(element, names):
     names = set((i.upper() for i in names))
     element.addCondition(lambda x: x[0].upper() not in names)
 
-class BaseDefinitionContainer(BaseDefinition):
+class BaseContainerDefinition(BaseDefinition):
 
     """ Force order of its members """
     force_order = False
@@ -507,10 +511,10 @@ class BaseDefinitionContainer(BaseDefinition):
        return not self._members.first_item().name_in_grammar
 
     def parse_file(self, file, return_value_only=True):
-        return self.parse_return(self.grammar().parseFile(file, True), return_value_only)
+      return self.parse_return(self.grammar().parseFile(file, **{ _parse_all_name: True } ), return_value_only)
 
     def parse(self, str, whole_string=True, return_value_only=True):
-        return self.parse_return(self.grammar().parseString(str, whole_string), return_value_only)
+      return self.parse_return(self.grammar().parseString(str, **{ _parse_all_name: whole_string} ), return_value_only)
 
     def parse_return(self, val, return_value_only=True):
         val = val[0]
@@ -527,7 +531,7 @@ class BaseDefinitionContainer(BaseDefinition):
 
 
 
-class BaseSectionDefinition(BaseDefinitionContainer):
+class BaseSectionDefinition(BaseContainerDefinition):
    """ Base class for sections in Pot or InputParameters file """
 
 
@@ -557,7 +561,7 @@ class BaseSectionDefinition(BaseDefinitionContainer):
         return out
 
 
-class ConfDefinition(BaseDefinitionContainer):
+class ConfDefinition(BaseContainerDefinition):
 
    name_in_grammar = False
    """ No data are given just by a section name - no Flag equivalent for sections """
